@@ -265,13 +265,14 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
     mpl.rcParams.update(pgf_with_latex)
     n_modes = len(modes)
     n_kpoints = len(ZQS[:,0,0])
+
     for n in range(n_kpoints): #iterating over the k points
         fig, axs = plt.subplots(n_modes, sharex=True, sharey=True, gridspec_kw={'hspace': 0})
         if not (type(axs) == np.ndarray):
             axs = [axs]
         for i in range(n_modes): #iterating over the modes
             mode = modes[i]
-            axs[i].plot(np.repeat(freqs_from_disp[mode,n],100),np.linspace(0,ZQS[n,:,0].max(),100),c='r', label='freq from dispersion')
+            axs[i].plot(np.repeat(freqs_from_disp[mode,n],100),np.linspace(0,ZQS[:,0,n].max(),100),c='r', label='freq from dispersion')
             axs[i].plot(freq,ZQS[n,:,0], ':', color='grey')
             axs[i].text(.75,.75,labels[n]+str('\n mode')+str(mode),fontsize=12,horizontalalignment='center', verticalalignment='center',transform=axs[i].transAxes)
             axs[i].plot(freq, ZQS[n,:,mode+1])
@@ -285,8 +286,8 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
         plt.xlabel('Frequency [Thz]')
 #        plt.tight_layout()
         
-        plt.show() 
-        fig.savefig('plot2_'+str(n)+'.pdf')
+    plt.show() 
+    fig.savefig('plot2.pdf')
     return
 
 
@@ -374,7 +375,7 @@ def plot4(kk, kk_MD, frequencies, frequencies_disp, x_labels, DOS_info):
 
     for j in range(0,n_branches):
         # graph_MD = ax.scatter(kk_MD, frequencies_MD[0,j,:], color='blue', label='MD frequencies')
-        graph_ft, = ax.plot(kk, frequencies[0,j,:], color='red', label='finite T dispersion', linewidth=1)
+        graph_ft = ax.scatter(kk_MD, frequencies[0,j,:], color='red', label='finite T dispersion', linewidth=1)
         graph_disp, = ax.plot(kk, frequencies_disp[0,j,:], color='black', label='0K dispersion', linewidth=1)
 #        f_gamma = interpolate.interp1d(kk, frequencies[1,j,:], kind=1)
 #        y1, y2 = f(x)+f_gamma(x)/2, f(x)-f_gamma(x)/2
@@ -392,7 +393,7 @@ def plot4(kk, kk_MD, frequencies, frequencies_disp, x_labels, DOS_info):
     graph_DOS_finiteK,= ax2.plot(DOS_ft,freq_DOS, c='red', label = 'finte K DOS')
 
     ax2.set_xticks([])
-    ax2.tick_params(axis='y', which='major', labelsize=0.0, width=2 , length=6, direction='in', top=True, right=True)
+    ax2.tick_params(axis='y', which='major', labelsize=0.0000001, width=2 , length=6, direction='in', top=True, right=True)
     ax2.legend()
     
     
