@@ -45,6 +45,8 @@ def read_parameters(input_file):
     
     DT = float(lista[8])
     
+    Nb = int(lista[9])
+    
     
 
             
@@ -54,7 +56,7 @@ def read_parameters(input_file):
 #    max_Z = float(lista[15])
     
     f.close()
-    return  Masses, n_atom_unit_cell, N1,N2,N3, ks, file_FC, file_trajectory, file_initial_conf, DT
+    return  Masses, n_atom_unit_cell, N1,N2,N3, ks, file_FC, file_trajectory, file_initial_conf, DT, Nb
 
 
 
@@ -107,97 +109,11 @@ def read_post_proc(input_file):
     temperature_folders = lista[13]
     
     NAC = bool(int(lista[14]))
-     
-    return plot_types, Masses, n_atom_unit_cell, N1, N2, N3, file_forces, file_SPOSCAR, max_Z, gaussian_smoothing, interp, kpoints, labels, modes, temperature_folders, NAC
-
-
-
-
-
-def read_phonopy(file_eigenvectors, n_atom_unit_cell):
-    ## =============================================================================
-    # Phonopy frequencies and eigenvectors
-    data = yaml.load(open(file_eigenvectors))
-    #D = data['phonon'][0]['dynamical_matrix']
-    #D = np.array(D)
-    #D_real, D_imag = D[:,0::2], 1j*D[:,1::2]
-    #D = (D_real + D_imag)*21.49068**2#*0.964*10**(4)#
     
-#    data2 = data['phonon']
-#    qpoints_scaled = []
-#    freqs = []
-#    eigvecs = []
-#    for element in data2:
-#        qpoints_scaled.append(element['q-position'])
-#        freq = []
-#        eigvec = np.zeros((n_atom_unit_cell*3, n_atom_unit_cell*3),dtype=complex)
-#        for j in range(len(element['band'])):
-#            branch = element['band'][j]
-#            freq.append(branch['frequency'])
-#            
-#            eigen = np.array(branch['eigenvector'],dtype=complex)
-#            eigen_real = eigen[:,:,0]
-#            eigen_imag = eigen[:,:,1]
-#            eigen = eigen_real + 1j*eigen_imag
-#            eigen = eigen.reshape(n_atom_unit_cell*3,)
-#            eigvec[:,j] = eigen
-#    
-#        freqs.append(freq)
-#        eigvecs.append(eigvec)
-#    qpoints_scaled = np.array(qpoints_scaled)
-#    freqs = np.array(freqs)
-    c = 1.88973 #conversion to Bohrs
-    Hk = np.array(data['reciprocal_lattice'])*2*np.pi*1/c
-    distances = []
-    qpoints_scaled = []
-    dist = 0.0
-    frequencies = []
-    eigvecs = []
-    for i in range(len(data['phonon'])):
-        if(i==0):
-            this_element = data['phonon'][i]
-            this_qpoint_sc = this_element['q-position']
-            dist = 0.0
-            distances.append(dist)
-        else:
-            this_element = data['phonon'][i]
-            previous_element = data['phonon'][i-1]
-            this_qpoint_sc = this_element['q-position']
-            previous_qpoint_sc =  previous_element['q-position']
-            
-            this_qpoint = np.dot(Hk,this_qpoint_sc)
-            previous_qpoint = np.dot(Hk,previous_qpoint_sc)
-            
-            diff = this_qpoint - previous_qpoint
-            
-            dist = dist + np.linalg.norm(diff)
-            distances.append(dist)
-        
-        prov = []
-        eigvec = np.zeros((n_atom_unit_cell*3, n_atom_unit_cell*3),dtype=complex)
-        for j in range(len(this_element['band'])):
-            branch = this_element['band'][j]
-            prov.append(branch['frequency'])
-            eigen = np.array(branch['eigenvector'],dtype=complex)
-            eigen_real = eigen[:,:,0]
-            eigen_imag = eigen[:,:,1]
-            eigen = eigen_real + 1j*eigen_imag
-            eigen = eigen.reshape(n_atom_unit_cell*3,)
-            eigvec[:,j] = eigen
-            
-        eigvecs.append(eigvec)
-        frequencies.append(prov)
-        qpoints_scaled.append(this_qpoint_sc)
+    appendix = lista[15].strip()
 
-    frequencies = np.array(frequencies)
-    distances = np.array(distances)
-    qpoints_scaled = np.array(qpoints_scaled)
-    Nqpoints = len(qpoints_scaled[:,0])
+    return plot_types, Masses, n_atom_unit_cell, N1, N2, N3, file_forces, file_SPOSCAR, max_Z, gaussian_smoothing, interp, kpoints, labels, modes, temperature_folders, NAC, appendix
 
-    
-    ks = np.dot(Hk,qpoints_scaled.T).T
-    # =============================================================================
-    return Nqpoints, qpoints_scaled, ks, frequencies, eigvecs, distances, Hk
 
 
 def read_SPOSCAR_and_masses(file, n_atom_primitive_cell, Masses, N1, N2, N3):
